@@ -43,14 +43,20 @@ __all__ = (
     "KmsGrantConfigurationTypeDef",
     "KmsGrantConstraintsTypeDef",
     "KmsKeyConfigurationTypeDef",
+    "LocationTypeDef",
     "NetworkOriginConfigurationTypeDef",
+    "PathElementTypeDef",
+    "PositionTypeDef",
     "S3AccessPointConfigurationTypeDef",
     "S3BucketAclGrantConfigurationTypeDef",
     "S3BucketConfigurationTypeDef",
     "S3PublicAccessBlockConfigurationTypeDef",
     "SecretsManagerSecretConfigurationTypeDef",
+    "SpanTypeDef",
     "SqsQueueConfigurationTypeDef",
     "StatusReasonTypeDef",
+    "SubstringTypeDef",
+    "ValidatePolicyFindingTypeDef",
     "VpcConfigurationTypeDef",
     "CreateAccessPreviewResponseTypeDef",
     "CreateAnalyzerResponseTypeDef",
@@ -69,6 +75,7 @@ __all__ = (
     "ListTagsForResourceResponseTypeDef",
     "PaginatorConfigTypeDef",
     "SortCriteriaTypeDef",
+    "ValidatePolicyResponseTypeDef",
 )
 
 _RequiredAccessPreviewFindingTypeDef = TypedDict(
@@ -417,12 +424,24 @@ KmsKeyConfigurationTypeDef = TypedDict(
     total=False,
 )
 
+LocationTypeDef = TypedDict(
+    "LocationTypeDef", {"path": List["PathElementTypeDef"], "span": "SpanTypeDef"}
+)
+
 NetworkOriginConfigurationTypeDef = TypedDict(
     "NetworkOriginConfigurationTypeDef",
     {"internetConfiguration": Dict[str, Any], "vpcConfiguration": "VpcConfigurationTypeDef"},
     total=False,
 )
 
+PathElementTypeDef = TypedDict(
+    "PathElementTypeDef",
+    {"index": int, "key": str, "substring": "SubstringTypeDef", "value": str},
+    total=False,
+)
+
+PositionTypeDef = TypedDict("PositionTypeDef", {"column": int, "line": int, "offset": int})
+
 S3AccessPointConfigurationTypeDef = TypedDict(
     "S3AccessPointConfigurationTypeDef",
     {
@@ -461,6 +480,8 @@ SecretsManagerSecretConfigurationTypeDef = TypedDict(
     "SecretsManagerSecretConfigurationTypeDef", {"kmsKeyId": str, "secretPolicy": str}, total=False
 )
 
+SpanTypeDef = TypedDict("SpanTypeDef", {"end": "PositionTypeDef", "start": "PositionTypeDef"})
+
 SqsQueueConfigurationTypeDef = TypedDict(
     "SqsQueueConfigurationTypeDef", {"queuePolicy": str}, total=False
 )
@@ -477,6 +498,19 @@ StatusReasonTypeDef = TypedDict(
     },
 )
 
+SubstringTypeDef = TypedDict("SubstringTypeDef", {"length": int, "start": int})
+
+ValidatePolicyFindingTypeDef = TypedDict(
+    "ValidatePolicyFindingTypeDef",
+    {
+        "findingDetails": str,
+        "findingType": Literal["ERROR", "SECURITY_WARNING", "SUGGESTION", "WARNING"],
+        "issueCode": str,
+        "learnMoreLink": str,
+        "locations": List["LocationTypeDef"],
+    },
+)
+
 VpcConfigurationTypeDef = TypedDict("VpcConfigurationTypeDef", {"vpcId": str})
 
 CreateAccessPreviewResponseTypeDef = TypedDict("CreateAccessPreviewResponseTypeDef", {"id": str})
@@ -608,3 +642,16 @@ PaginatorConfigTypeDef = TypedDict(
 SortCriteriaTypeDef = TypedDict(
     "SortCriteriaTypeDef", {"attributeName": str, "orderBy": Literal["ASC", "DESC"]}, total=False
 )
+
+_RequiredValidatePolicyResponseTypeDef = TypedDict(
+    "_RequiredValidatePolicyResponseTypeDef", {"findings": List["ValidatePolicyFindingTypeDef"]}
+)
+_OptionalValidatePolicyResponseTypeDef = TypedDict(
+    "_OptionalValidatePolicyResponseTypeDef", {"nextToken": str}, total=False
+)
+
+
+class ValidatePolicyResponseTypeDef(
+    _RequiredValidatePolicyResponseTypeDef, _OptionalValidatePolicyResponseTypeDef
+):
+    pass
